@@ -10,6 +10,7 @@ from algolink.runtime.server import BaseHTTPServer, HTTPServerConfig, MalformedH
 from algolink.utils.fs import current_module_path
 from algolink.utils.log import rlogger
 
+from gunicorn.app.base import BaseApplication
 
 current_app = None
 
@@ -17,6 +18,7 @@ current_app = None
 def create_executor_function(interface: Interface, method: str):
     """
     Creates a view function for specific interface method
+
     :param interface: :class:`.Interface` instance
     :param method: method name
     :return: callable view function
@@ -74,13 +76,34 @@ if Core.DEBUG:
     FlaskConfig.log_params()
 
 PREBUILD_PATH = current_module_path('prebuild')
-BASE_IMAGE_TEMPLATE = 'zyfraai/flask:{}'
+BASE_IMAGE_TEMPLATE = 'algolink/flask:{}'
 
+_host = HTTPServerConfig.host
+_port = HTTPServerConfig.port
+options = {
+    'bind': '{0}:{1}'.format(_host, _port),
+    'workers': 2,#multiprocessing.cpu_count(),
+}
 
 def prebuild_hook(python_version):
-    from algolink.ext.docker.prebuild import prebuild_image
+    from ..docker.prebuild import prebuild_image
     prebuild_image(PREBUILD_PATH, BASE_IMAGE_TEMPLATE, python_version)
 
+class APPServer(BaseApplication):
+    def __init__(self, app, options=None):
+        self.options = options or {}
+        self.application = app
+        super().__init__()
+
+    def load_config(self):
+        config = {key: value for key, value in self.options.items()
+                  if key in self.cfg.settings and value is not None}
+        for key, value in config.items():
+            self.cfg.set(key.lower(), value)
+        self.cfg.set("worker_class","gevent")
+
+    def load(self):
+        return self.application
 
 class FlaskServer(BaseHTTPServer):
     """
@@ -97,6 +120,9 @@ class FlaskServer(BaseHTTPServer):
         'run_cmd': False,  # base image has already specified command
         'prebuild_hook': prebuild_hook
     }}
+    def __init__(self,port=9000,serve_method="gun"):
+        self.input_port = port
+        self.serve_method = serve_method
 
     def _create_app(self):
         from flasgger import Swagger
@@ -132,6 +158,7 @@ class FlaskServer(BaseHTTPServer):
     def run(self, interface: Interface):
         """
         Starts flask service
+
         :param interface: runtime interface to expose via HTTP
         """
         global current_app
@@ -141,13 +168,25 @@ class FlaskServer(BaseHTTPServer):
         current_app = app
         if FlaskConfig.run_flask:
             rlogger.debug('Running flask on %s:%s', HTTPServerConfig.host, HTTPServerConfig.port)
-            app.run(HTTPServerConfig.host, HTTPServerConfig.port)
+            #app.run(HTTPServerConfig.host, HTTPServerConfig.port)
+            if self.input_port!=9000:
+                _new_port = self.input_port
+            else:
+                _new_port = HTTPServerConfig.port
+            ops = {
+                'bind': '{0}:{1}'.format(HTTPServerConfig.host,_new_port),
+                'workers': 2,#multiprocessing.cpu_count(),
+            }
+            if self.serve_method=="uwsgi":
+                app.run(HTTPServerConfig.host, HTTPServerConfig.port)
+            else:
+                APPServer(app, ops).run()
         else:
             rlogger.debug('Skipping direct flask application run')
 
 
 def main():
-    from algolink.ext.docker.prebuild import prebuild_missing_images
+    from ..docker.prebuild import prebuild_missing_images
     prebuild_missing_images(PREBUILD_PATH, BASE_IMAGE_TEMPLATE)
 
 
